@@ -1,8 +1,7 @@
 """Matcher helpers.
 
-A "matcher" is a helper class with an `__eq__` method defined. Use them
-anywhere in your test where you would use an actual value for equality
-(`==`) comparision.
+A "matcher" is a class with an `__eq__` method defined. Use them anywhere
+in your test where you would use an actual value for equality (`==`) comparision.
 
 Matchers help you loosen assertions where strict adherence to an exact value
 is not relevent to what you're trying to test.
@@ -22,7 +21,7 @@ Example:
 
 Note:
     Identity comparisons (`is`) will not work with matchers. Decoy only uses
-    equality comparisons for stubbing and verification.
+    equality comparisons (`==`) for stubbing and verification.
 """
 from re import compile as compile_re
 from typing import cast, Any, List, Mapping, Optional, Pattern, Type
@@ -233,9 +232,7 @@ class _StringMatching:
 
     def __eq__(self, target: object) -> bool:
         """Return true if target is not self._reject_value."""
-        return (
-            type(target) is str and self._pattern.search(cast(str, target)) is not None
-        )
+        return isinstance(target, str) and self._pattern.search(target) is not None
 
     def __repr__(self) -> str:
         """Return a string representation of the matcher."""
